.. _user-guide:

**********
User Guide
**********
MolSystem is a Python package for storing molecular and periodic (crystalline)
systems. It provides and object oriented interface over an underly SQL database that
handles systems with multiple configurations, plus templates and subsets. You can
loosely think of a system as being an abstract molecular or periodic system and the
configurations as the physical instances with the coordinates, bonds, etc. that describe
different structures, conformers, or frames in a trajectory.

..
   The following sections cover accessing and controlling this functionality.

   .. toctree::
      :maxdepth: 2
      :titlesonly:

Index
=====

* :ref:`genindex`
